<?php
/**
 * Plugin Name: Dynamic Pricing for WooCommerce
 * Plugin URI:
 * Description: WordPress Plugin Dynamic Prices
 * Version: 1.0.1.1
 * Author: BeRocket
 * Requires at least: 5.0
 * Author URI: http://berocket.com
 * Text Domain: BeRocket_Dynamic_Pricing_domain
 * Domain Path: /languages/
 */
if(! defined( 'ABSPATH' ) ) exit;

load_plugin_textdomain( 'BeRocket_Dynamic_Pricing_domain', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

class BeRocket_Dynamic_Pricing {
	
	
	
	public function __construct() {
		// Register plugin settings
		add_action( 'admin_init' , array( $this, 'register_settings' ) );
		// Add settings page to menu
		add_action( 'admin_menu' , array( $this, 'add_menu_item' ) );
		//Aplly coupon
		add_action( 'wp_head' ,  array( $this, 'apply_coupon' ) );
		//Apply discount for product group
		add_action( 'woocommerce_cart_calculate_fees', array( $this, 'discount_for_set_of_products' ) );
		//Remove message "Coupon code was successfully added."
		add_filter( 'woocommerce_coupon_message', array( $this,'remove_msg_filter' ), 10, 3 ) ;
		//Delete discount rule
		add_action('wp_ajax_RemoveRule', array($this, 'removeRule'));
		//Update status discount rule
		add_action('wp_ajax_UpdateStatus', array($this, 'updateStatus'));
		//Delete all coupons that were created by the plugin
		register_deactivation_hook( __FILE__, array( $this, 'br_plugin_deactivate' ) );
		register_activation_hook(__FILE__, array( $this, 'br_plugin_activate' ) );
	}

	/**
	 * Delete all coupons created by the plugin
	 * @return void
	 */
	public function plugin_deactivate () {
		$posts = array( 'post_type' => 'shop_coupon', 's' => 'br_unique' );
		$results = new WP_Query( $posts );
		while ( $results->have_posts() ) {
			$results->the_post();
			$ID = $results->post->ID;
			wp_delete_post($ID);
		}
	}
	
	public function br_plugin_activate() {
			$options = get_option( 'berocket_dynamic_pricing' );
			$add_option_value = array("br_opened_tab" => "coupons");
			update_option( 'berocket_dynamic_pricing', array_merge( $options, $add_option_value ) );
	}

	/**
	 * Add settings page to admin menu
	 * @return void
	 */
	public function add_menu_item() {
		add_submenu_page( 'woocommerce', __( 'Dynamic Pricing Settings', 'BeRocket_Dynamic_Pricing_domain' ), __( 'Dynamic Pricing ', 'BeRocket_Dynamic_Pricing_domain' ), 'manage_options' ,
		'Dynamic_Pricing_Settings', array( $this, 'output_page' ), '' );
		$this->generate_coupon();
		$this->generate_set_of_products_rule();
	}

	/**
	 * Register plugin settings
	 * @return void
	 */
	public function register_settings() {
		register_setting( 'berocket_dynamic_pricing_settings', 'berocket_dynamic_pricing' );
	}
	
	/**
	 * Load page content
	 * @return void
	 */
	public function output_page() {
		wp_enqueue_script ( 'br-dynamic-pricing-script', plugins_url( 'js/admin.js', __FILE__ ), array ('jquery'), null, true );
		wp_enqueue_style( 'DynamicPricingStylesheet', plugins_url( 'css/style.css', __FILE__ ), "", 1.0 );
		wp_enqueue_script('wc-enhanced-select');
		wp_enqueue_style('woocommerce_admin_styles', plugins_url( 'css/dynamic_pricing_plugin_admin.css', __FILE__ ), "", 1.0 );
		wp_enqueue_style('dynamic_pricing_styles', plugins_url( 'css/bootstrap.min.css', __FILE__ ), "", 1.0 );
		wp_enqueue_script( 'woocommerce_admin' );
		
		
		$options = get_option( 'berocket_dynamic_pricing' );
		$tabs_array = array( 'coupons', 'products' );
	?>
	<div class="wrap">
		<form method="post" action="options.php">
		<?php settings_fields( 'berocket_dynamic_pricing_settings' ); ?>
		<h2 class="nav-tab-wrapper settings_tabs">
			<a href="#coupons" class="nav-tab <?php if($options['br_opened_tab'] == 'coupons' || !in_array( $options['br_opened_tab'], $tabs_array ) ) echo 'nav-tab-active'; ?>"><?php _e('Coupons', 'BeRocket_Dynamic_Pricing_domain') ?></a>
			<a href="#products" class="nav-tab <?php if($options['br_opened_tab'] == 'products' ) echo 'nav-tab-active'; ?>"><?php _e('Products', 'BeRocket_Dynamic_Pricing_domain') ?></a>
		</h2>
		
		<div id="coupons" class="tab-item <?php if($options['br_opened_tab'] == 'coupons' || !in_array( $options['br_opened_tab'], $tabs_array ) ) echo 'current'; ?>">
			<?php
			_e( '<h2>Create a coupon</h2>', 'BeRocket_Dynamic_Pricing_domain' );
			echo '<table class = "form-table">';
				echo '<tr> <th>' . __( 'Minimum subtotal', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><input type = "number" name = "berocket_dynamic_pricing[cart_total]" min = "1" placeholder = "0" value = "" ></td> </tr>';
				echo '<tr> <th>' . __( 'Discount type', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><select name = "berocket_dynamic_pricing[coupon_discount_type]" id = "case_discount_coupons">';
						echo '<option>%</option>';
						echo '<option>'.get_woocommerce_currency_symbol().'</option>';
					echo '</select></td></tr>';
				echo '<tr> <th>' . __( 'Amount of discount', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><input type = "number" id = "value_coupon_discount" name = "berocket_dynamic_pricing[value_coupon_discount]" min = "0" max = "100" placeholder = "0" value = ""></td></tr>';
			echo '</table>';
			?>
			<div id="rule">
				<table class="wp-list-table widefat fixed striped posts">
					<thead>
					<tr>
						<td style = "text-align: center;"><?php esc_html_e('Code coupon', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Minimum subtotal', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Amount of discount', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Discount Type', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Action', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
					</tr>
					</thead>
					<tbody id="rule">
					<?php
					$posts = array( 'post_type' => 'shop_coupon', 's'=> 'br_unique' );
					$results = new WP_Query( $posts );
						while ( $results->have_posts() ) {
							$results->the_post();
							$ID = $results->post->ID;
							$title = $results->post->post_title;
							$status = $results->post->post_status;
							$class = 'btn btn-success';
							if ($status == 'publish') {
								$class = 'btn btn-success';
								$value = __('Disable', 'BeRocket_Dynamic_Pricing_domain');
							} else {
								$class = 'btn btn-danger';
								$value = __('Enable', 'BeRocket_Dynamic_Pricing_domain');
							}
							?>
							<tr>
								<td style = "text-align: center;"><?php echo '<a href = "post.php/?post='.$ID.'&action=edit">'.$title."</a>";?></td>
								<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'minimum_amount', true ); ?></td>
								<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'coupon_amount', true ); ?></td>
								<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'discount_type', true ); ?></td>
								<td style = "text-align: center;">
									<a class="<?php echo $class; ?> manage_status" id="state_<?php echo $ID ?>">
										<?php echo $value; ?>
									</a>
									<a class="btn btn-danger delete_rule" id="delete_<?php echo $ID ?>">
										<?php _e('Delete', 'BeRocket_Dynamic_Pricing_domain'); ?>
									</a>
								</td>
							</tr>
						<?php
						}
						?>
						</tbody>
					</table>
				<input type="hidden" name="form" value="rules">
				<input type="hidden" id="ajax_path" value="<?php echo admin_url('admin-ajax.php') ?>">
			</div>
		</div>
		<div id="products" class="tab-item <?php if($options['br_opened_tab'] == 'products' ) echo 'current'; ?>">
<!--
		<div class="nav-block products-block">
-->
			<?php
			_e( '<h2>Creating a discount depending on whether there are these products in the basket</h2>', 'BeRocket_Dynamic_Pricing_domain' );
			echo '<table class = "form-table">';
				echo '<tr> <th>' . __( 'Select first product', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
				?>
					<td><select class="wc-product-search" style="width: 30%;height:30px" id="product_id" name = "berocket_dynamic_pricing[select_product_one]" data-placeholder="<?php esc_attr_e('Search for a product&hellip;', 'woocommerce'); ?>" data-action="woocommerce_json_search_products_and_variations">
					<?php
					$product_id = !empty($_REQUEST['product_id']) ? $_REQUEST['product_id'] : array();  // selected product ids
					$product = wc_get_product($product_id);
					if (is_object($product)) {
						echo '<option value="' . esc_attr($product_id) . '"' . selected(true, true, false) . '>' . wp_kses_post($product->get_formatted_name()) . '</option>';
					}
					echo '</select></td>
				</tr>';
				echo '<tr> <th>' . __( 'Amount of product' , 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><input type = "number" name = "berocket_dynamic_pricing[count_product_one]"  min = "0" max = "1000000" placeholder = "0" value = "" ></td> </tr>';
				echo '<tr> <th>' . __( 'Select second product' , 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
				?>
					<td><select class="wc-product-search" style="width: 30%;height:30px" id="product_id" name = "berocket_dynamic_pricing[select_product_two]" data-placeholder="<?php esc_attr_e('Search for a product&hellip;', 'woocommerce'); ?>" data-action="woocommerce_json_search_products_and_variations">
					<?php
					$product_id = !empty($_REQUEST['product_id']) ? $_REQUEST['product_id'] : array();  // selected product ids
						$product = wc_get_product($product_id);
						if (is_object($product)) {
							echo '<option value="' . esc_attr($product_id) . '"' . selected(true, true, false) . '>' . wp_kses_post($product->get_formatted_name()) . '</option>';
						}
				echo '</select></td></tr>';
				echo '<tr> <th>' . __( 'Amount of product' , 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><input type = "number" name = "berocket_dynamic_pricing[count_product_two]"  min = "0" max = "1000000" placeholder = "0" value = "" ></td> </tr>';
				echo '<tr> <th>' . __( 'Discount type', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
					echo '<td><select name= "berocket_dynamic_pricing[products_discount_type]" id = "case_discount_products">';
						echo '<option>%</option>';
						echo '<option>'. get_woocommerce_currency_symbol() .'</option>';
					echo '</select></td></tr>';
				echo '<tr> <th>' . __( 'Amount of discount', 'BeRocket_Dynamic_Pricing_domain' ) . '</th>';
				echo '<td><input type = "number" id = "value_products_discount" name = "berocket_dynamic_pricing[value_products_discount]" min = "0" max = "100" placeholder = "0" value = ""></td></tr>';
			echo '</table>';
			?>
			<div id="rule">
				<table class="wp-list-table widefat fixed striped posts">
					<thead>
					<tr>
						<td style = "text-align: center;"><?php esc_html_e('First Product', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Amount Product One', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Second Product', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Amount Product Two', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Amount of discount', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Discount Type', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
						<td style = "text-align: center;"><?php esc_html_e('Action', 'BeRocket_Dynamic_Pricing_domain'); ?></td>
					</tr>
					</thead>
					<tbody id="rule">
					<?php
					$posts = array( 'post_type' => 'discount');
					$results = new WP_Query( $posts );
					while ( $results->have_posts() ) {
						$results->the_post();
						$ID = $results->post->ID;
						$title = $results->post->post_title;
						$status = $results->post->post_status;
						$class = 'btn btn-success';
						if ($status == 'publish') {
							$class = 'btn btn-success';
							$value = __('Disable', 'BeRocket_Dynamic_Pricing_domain');
						} else {
							$class = 'btn btn-danger';
							$value = __('Enable', 'BeRocket_Dynamic_Pricing_domain');
						}
						$product_one_id = get_post_meta( $ID, 'product one', true );
						$product_two_id = get_post_meta( $ID, 'product two', true );
						?>
						<tr>
							<td style = "text-align: center;"><?php echo get_the_title($product_one_id); ?></td>
							<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'count_product_one', true ); ?></td>
							<td style = "text-align: center;"><?php echo get_the_title($product_two_id); ?></td>
							<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'count_product_two', true ); ?></td>
							<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'value_discount', true ); ?></td>
							<td style = "text-align: center;"><?php echo get_post_meta( $ID, 'type_discount', true ); ?></td>
							<td style = "text-align: center;">
								<a class="<?php echo $class; ?> manage_status" id="state_<?php echo $ID ?>">
										<?php echo $value; ?>
								</a>
								<a class="btn btn-danger delete_rule" id="delete_<?php echo $ID ?>">
									<?php _e('Delete', 'BeRocket_Dynamic_Pricing_domain'); ?>
								</a>
							</td>
						</tr>
					<?php
					}
					?>
					</tbody>
				</table>
				<input type="hidden" name="form" value="rules">
				<input type="hidden" id="ajax_path" value="<?php echo admin_url('admin-ajax.php') ?>">
			</div>
			
		</div>
		<input type="hidden" id="br_opened_tab" name="berocket_dynamic_pricing[br_opened_tab]" value="<?php echo $options['br_opened_tab'] ?>">
		<p class="submit">
			<?php
			echo '<input name="Submit" type="submit" class="button-primary" value="' . __( 'Save Settings', 'BeRocket_Dynamic_Pricing_domain' ) . '" />';
			//delete_option('berocket_dynamic_pricing');
			?>
		</p>
		</form>
	</div>
	<?php
	}

	/*
	 * Update rule status
	 * @return void
	 */
	public function updateStatus()
	{
		$data = $_POST;
		$ID =  $data['id'];
		$status = get_post_status($ID);
		if ($ID) {
			if ($status == 'publish') {
				wp_update_post(array(
					'ID'    =>  $ID,
					'post_status'   => 'draft'
					));
			} elseif ($status == 'draft') {
				wp_update_post(array(
					'ID'    =>  $ID,
					'post_status'   => 'publish'
					));
			}
			echo $state;
		}
		die();
	}

	/*
	 * Delete rule
	 * @return void
	 */
	public function removeRule()
	{
		$data = $_POST;
		$ID =  $data['id'];
		if ($ID) {
			try {
				$id = intval($ID);
				if (!$id) return false;
				wp_delete_post($ID);
			} catch (Exception $e) {
			}
		}
		die();
	}

	/**
	 * Get quantity of the product by id
	 * @param string Product ID
	 * @return int, Int quantity of product
	 */
	public function get_count_product( $product_id ) {
		$cart = WC()->instance()->cart;
		$id = $product_id;
		foreach ( $cart->cart_contents as $cart_item_key => $cart_item ) {
			if ( $cart->cart_contents[$cart_item_key]['product_id'] == $id ) {
				$cnt_products = $cart->cart_contents[$cart_item_key]['quantity'];
				break;
			}
			else {
				$cnt_products = 0;
			}
		}
		return $cnt_products;
	}

	/**
	 * Get price of the cart without delivery
	 * @return int, Int price cart without delivery
	 */
	public function return_cart_total() {
		if ( ! WC()->cart->prices_include_tax ) {
			$cart_total = WC()->cart->get_subtotal();
		} else {
			$cart_total = WC()->cart->get_subtotal() + WC()->cart->tax_total;
		}
		return $cart_total;
	}

	/**
	 * Get all coupons from database
	 * @return array
	 */
	public function get_all_coupons() {
		global $wpdb;
		$coupons = array();
		$pages = $wpdb->get_results(
			"SELECT ID,post_title
			FROM $wpdb->posts
			WHERE post_status = 'publish' AND post_content = 'br_unique'
			AND post_type = 'shop_coupon'" );
		foreach ( $pages as $value ) {
			$coupons[ get_post_meta($value->ID, 'minimum_amount', true ) ] = $value->post_title;
		}
		krsort( $coupons );
		return $coupons;
	}

	/**
	 * Check cart for the amount suitable for the coupon
	 * @return string, Int coupon ID
	 */
	public function check_coupon_total() {
		foreach ( $this->get_all_coupons() as $amount => $coupon ) {
			if ( $amount <= $this->return_cart_total() ) {
				return $coupon;
			}
		}
	}

	/**
	 * Gives a discount on the cart depending on the number of individual products
	 * @return void
	 */
	public function discount_for_set_of_products () {
		$options = get_option( 'berocket_dynamic_pricing' );
		$product_ids = array();
		foreach( WC()->cart->get_cart() as $cart_item ){
			$product_id = $cart_item['product_id'];
			array_push($product_ids, $product_id);
		}
		if(count($product_ids) >= 2) {
			$posts = array(
				'post_type' => 'discount',
				'meta_query' => array(
					array(
						'key' => 'product one',
						'value' => $product_ids
					),
					array(
						'key' => 'product two',
						'value' => $product_ids
					),
				)
			);
			$results = new WP_Query( $posts );
			while ( $results->have_posts() ) {
				$results->the_post();
				$ID = $results->post->ID;
				$product_one = get_post_meta ( $ID, 'product one', true );
				$product_two = get_post_meta ( $ID, 'product two', true );
				$type_discount = get_post_meta ( $ID, 'type_discount', true );
				$count_product_one = get_post_meta ( $ID, 'count_product_one', true  );
				$count_product_two = get_post_meta ( $ID, 'count_product_two', true  );
				if ( $product_one != $product_two ) {
					$count_product_1 	= $this->get_count_product( $product_one );
					$count_product_2 	= $this->get_count_product( $product_two );
					$applied_coupon		= WC()->cart->get_applied_coupons();
					$code_coupon 		= implode( $applied_coupon );
					$id_coupon 			= wc_get_coupon_id_by_code( $code_coupon );
					$coupons_obj 		= new WC_Coupon( $id_coupon );
					$coupons_amount 	= $coupons_obj->get_amount();
					$value_products_discount = get_post_meta ( $ID, 'value_discount', true  );
					if ( $type_discount == "%" ) {
						if ( $count_product_1 == $count_product_one and $count_product_2 == $count_product_two ) {
							$discount = ( WC()->cart->subtotal - ( WC()->cart->subtotal * ( $coupons_amount / 100 ) ) ) * ( $value_products_discount / 100 );
							WC()->cart->add_fee( __( 'Discount for a set of products', 'BeRocket_Dynamic_Pricing_domain' ), - $discount );
						}
					}
					elseif ( $type_discount == "$" ) {
						if ( $count_product_1 == $count_product_one and $count_product_2 == $count_product_two ) {
							WC()->cart->add_fee( __( 'Discount for a set of products', 'BeRocket_Dynamic_Pricing_domain' ), - $value_products_discount );
						}
					}
				}
			}
		}
	}

	/*
	 * Generate rule of set products
	 * @return void
	 */
	public function generate_set_of_products_rule () {
		$options = get_option( 'berocket_dynamic_pricing' );
		if( $options['count_product_one'] != '' and $options['count_product_two'] != '' ) {
			if ( isset($options['select_product_one'], $options['select_product_two'] ) ) {
				$post = array(
				 'post_title' 	=> 'test',
				 'post_name' 	=> '',
				 'post_content'	=> 'test',
				 'post_type' 	=> 'discount',
				 'post_status' 	=> 'publish',
				 'meta_input' 	=> array (
								'product one' => $options['select_product_one'],
								'product two' => $options['select_product_two'],
								'count_product_one' => $options['count_product_one'],
								'count_product_two' => $options['count_product_two'],
								'type_discount' => $options['products_discount_type'],
								'value_discount' => $options['value_products_discount'],
								)
				);
				$exist = false;
				$posts = array( 'post_type' => 'discount');
				$results = new WP_Query( $posts );
				while ( $results->have_posts() ) {
					$results->the_post();
					$ID = $results->post->ID;
					$product_one = get_post_meta ( $ID, 'product one', true );
					$product_two = get_post_meta ( $ID, 'product two', true );
					if ( $product_one == $options['select_product_one'] and $product_two == $options['select_product_two'] ) {
						$exist = true;
						echo " <script>alert('This rule already exists')</script>";
					}
				}
				if ( $exist == false ) {
					wp_insert_post($post);
				}
			}
		}
	}

	/**
	 * Apply coupon
	 * @return void
	 */
	public function apply_coupon() {
		$coupon = $this->check_coupon_total();
		if ( ! empty( WC()->cart->applied_coupons ) ) {
			if ( empty( $coupon ) ) {
				WC()->cart->remove_coupons();
			}
			else {
				WC()->cart->remove_coupons();
				WC()->cart->apply_coupon( $coupon );
			}
		} else {
			if ( $coupon and ! WC()->cart->apply_coupon( $coupon ) ) {
			}
			elseif ( ! $coupon ) {
				WC()->cart->remove_coupons();
			}
		}
	}

	/**
	 * Generate coupon
	 * @return void
	 */
	public function generate_coupon () {
		$options    = get_option( 'berocket_dynamic_pricing' );
		$exist      = false;
		$amount = $options['value_coupon_discount'];
		$cart_total = $options['cart_total'];
		if ( $options['coupon_discount_type'] == get_woocommerce_currency_symbol() ) {
			$discount_type = 'fixed_cart';
		} elseif ( $options['coupon_discount_type'] == '%' ) {
			$discount_type = 'percent';
		}
		if ( $cart_total != 0 and $amount != 0) {
			if ( $cart_total < 0 ) {
				$exist = true;
			}
			$coupons = $this->get_all_coupons();
			foreach ( $coupons as $key => $value ) {
				if ( $key == $cart_total ) {
					$exist = true;
				}
			}
			if ( $exist == false ) {
				$coupon_code = substr( "abcdefghijklmnopqrstuvwxyz123456789", mt_rand( 0, 50 ) , 1 ) .substr( md5( time() ), 1 ); // Code
				$coupon_code = substr( $coupon_code, 0, 5 ); // create 5 letters coupon
				$coupon = array(
					'post_title'   => $coupon_code,
					'post_content' => 'br_unique',
					'post_status'  => 'publish',
					'post_author'  => '',
					'post_type'    => 'shop_coupon'
				);
				$new_coupon_id = wp_insert_post( $coupon );
				// Add meta
				update_post_meta( $new_coupon_id, 'discount_type', $discount_type );
				update_post_meta( $new_coupon_id, 'coupon_amount', $amount );
				update_post_meta( $new_coupon_id, 'individual_use', 'yes' );
				update_post_meta( $new_coupon_id, 'product_ids', '' );
				update_post_meta( $new_coupon_id, 'exclude_product_ids', '' );
				update_post_meta( $new_coupon_id, 'usage_limit', '' );
				update_post_meta( $new_coupon_id, 'expiry_date', '' );
				update_post_meta( $new_coupon_id, 'apply_before_tax', 'no' );
				update_post_meta( $new_coupon_id, 'free_shipping', 'no' );
				update_post_meta( $new_coupon_id, 'exclude_sale_items', 'no' );
				update_post_meta( $new_coupon_id, 'free_shipping', 'no' );
				update_post_meta( $new_coupon_id, 'product_categories', '' );
				update_post_meta( $new_coupon_id, 'exclude_product_categories', '' );
				update_post_meta( $new_coupon_id, 'minimum_amount', $cart_total );
				update_post_meta( $new_coupon_id, 'customer_email', '' );
				update_post_meta( $new_coupon_id, 'unique', 'true' );
			} else {
				echo "<script type = 'text/javascript'>alert('A coupon for this basket amount already exists');</script>";
			}
		}
		update_option('berocket_dynamic_pricing', array ("cart_total" => "", "coupon_discount_type" => "", "value_coupon_discount" => "", "count_product_one" => "", "count_product_two" => "", "products_discount_type" => "", "value_products_discount" => "", "br_opened_tab" => $options['br_opened_tab']) );
	}

	/**
	 * Remove message "Coupon code was successfully added"
	 * @return string
	 */
	public function remove_msg_filter( $msg, $msg_code ) {
		return "";
	}
}
$BeRocket_Dynamic_Pricing_Plugin = new BeRocket_Dynamic_Pricing();
?>
